@@ -58,7 +58,8 @@ class CallbackConnector:
             # TODO: deprecated, remove this block in v1.3.0
             rank_zero_warn(
                 "Passing a ModelCheckpoint instance to Trainer(checkpoint_callbacks=...)"
-                " is deprecated since v1.1 and will no longer be supported in v1.3.",
+                " is deprecated since v1.1 and will no longer be supported in v1.3."
+                " Use `callbacks` argument instead.",
                 DeprecationWarning
             )
             self.trainer.callbacks.append(checkpoint_callback)
@@ -70,7 +71,7 @@ class CallbackConnector:
             )
 
         if not self._trainer_has_checkpoint_callbacks() and checkpoint_callback is True:
-            self.trainer.callbacks.append(ModelCheckpoint(dirpath=None, filename=None))
+            self.trainer.callbacks.append(ModelCheckpoint(dirpath=None, filename=None, mode='min'))
 
     def configure_progress_bar(self, refresh_rate=1, process_position=0):
         # smaller refresh rate on colab causes crashes, warn user about this
