@@ -19,7 +19,8 @@ class OptimizerConnector:
     def __init__(self, trainer):
         self.trainer = trainer
 
-    def on_trainer_init(self):
+    def on_trainer_init(self, enable_pl_optimizer):
+        self.trainer._enable_pl_optimizer = enable_pl_optimizer
         self.trainer.lr_schedulers = []
         self.trainer.optimizers = []
         self.trainer.optimizer_frequencies = []
