@@ -14,23 +14,21 @@
 import functools
 import importlib
 import queue as q
+import traceback
 from multiprocessing import Process, Queue
 
 import torch
 
-TORCHXLA_AVAILABLE = importlib.util.find_spec("torch_xla") is not None
-if TORCHXLA_AVAILABLE:
+XLA_AVAILABLE = importlib.util.find_spec("torch_xla") is not None
+
+if XLA_AVAILABLE:
     import torch_xla.core.xla_model as xm
-else:
-    xm = None
 
 
 def inner_f(queue, func, *args, **kwargs):  # pragma: no cover
     try:
         queue.put(func(*args, **kwargs))
     except Exception:
-        import traceback
-
         traceback.print_exc()
         queue.put(None)
 
@@ -41,10 +39,11 @@ def pl_multi_process(func):
         queue = Queue()
         proc = Process(target=inner_f, args=(queue, func, *args), kwargs=kwargs)
         proc.start()
-        proc.join(10)
+        proc.join(20)
         try:
             return queue.get_nowait()
         except q.Empty:
+            traceback.print_exc()
             return False
 
     return wrapper
@@ -66,7 +65,7 @@ class XLADeviceUtils:
         Return:
             Returns a str of the device hardware type. i.e TPU
         """
-        if xm is not None:
+        if XLA_AVAILABLE:
             return xm.xla_device_hw(device)
 
     @staticmethod
@@ -77,19 +76,29 @@ class XLADeviceUtils:
         Return:
             A boolean value indicating if the xla device is a TPU device or not
         """
-        if xm is not None:
+        if XLA_AVAILABLE:
             device = xm.xla_device()
             device_type = XLADeviceUtils._fetch_xla_device_type(device)
             return device_type == "TPU"
 
+    @staticmethod
+    def xla_available() -> bool:
+        """
+        Check if XLA library is installed
+
+        Return:
+            A boolean value indicating if a XLA is installed
+        """
+        return XLA_AVAILABLE
+
     @staticmethod
     def tpu_device_exists() -> bool:
         """
-        Public method to check if TPU is available
+        Runs XLA device check within a separate process
 
         Return:
             A boolean value indicating if a TPU device exists on the system
         """
-        if XLADeviceUtils.TPU_AVAILABLE is None and TORCHXLA_AVAILABLE:
+        if XLADeviceUtils.TPU_AVAILABLE is None and XLA_AVAILABLE:
             XLADeviceUtils.TPU_AVAILABLE = pl_multi_process(XLADeviceUtils._is_device_tpu)()
         return XLADeviceUtils.TPU_AVAILABLE
